package org.jrenner.android_glances;

import org.jrenner.glances.*;
import org.jrenner.glances.Process;

import java.net.MalformedURLException;
import java.net.URL;
import java.text.ParseException;
import java.util.Date;
import java.util.List;

/**
 * This class exists to hold all Glances data in a single data structure.
 * This makes using Android's AsyncTask much simpler

 */
public class GlancesData {
    private URL serverURL;
    private Glances server;
    // Data fields
    private Cpu cpu;
    private List<DiskIO> diskIO;
    private List<NetworkInterface> networkInterfaces;
    private List<FileSystem> fileSystems;
    private List<Sensor> sensors;
    private SystemInfo systemInfo;
    private int cores;
    private MemorySwap memorySwap;
    private Memory memory;
    private Load load;
    private Date lastUpdate;
    private Limits limits;
    private ProcessCount processCount;
    private List<Process> processList;

    public GlancesData(URL url) throws MalformedURLException, ParseException {
        serverURL = url;
        server = new Glances(serverURL);
        getData();
    }

    public void getData() throws MalformedURLException, ParseException {
        server = new Glances(serverURL);
        cpu = server.getCpu();
        diskIO = server.getDiskIO();
        networkInterfaces = server.getNetwork();
        fileSystems = server.getFs();
        sensors = server.getSensors();
        systemInfo = server.getSystem();
        cores = server.getCore();
        memorySwap = server.getMemSwap();
        memory = server.getMem();
        load = server.getLoad();
        lastUpdate = server.getNow();
        limits = server.getAllLimits();
        processCount = server.getProcessCount();
        processList = server.getProcessList();
    }

    public void setServerURL(URL serverURL) {
        this.serverURL = serverURL;
    }

    public URL getServerURL() {
        return serverURL;
    }

    public Glances getServer() {
        return server;
    }

    public Cpu getCpu() {
        return cpu;
    }

    public List<DiskIO> getDiskIO() {
        return diskIO;
    }

    public List<NetworkInterface> getNetworkInterfaces() {
        return networkInterfaces;
    }

    public List<FileSystem> getFileSystems() {
        return fileSystems;
    }

    public List<Sensor> getSensors() {
        return sensors;
    }

    public SystemInfo getSystemInfo() {
        return systemInfo;
    }

    public int getCores() {
        return cores;
    }

    public MemorySwap getMemorySwap() {
        return memorySwap;
    }

    public Memory getMemory() {
        return memory;
    }

    public Load getLoad() {
        return load;
    }

    public Date getLastUpdate() {
        return lastUpdate;
    }

    public Limits getLimits() {
        return limits;
    }

    public ProcessCount getProcessCount() {
        return processCount;
    }

    public List<Process> getProcessList() {
        return processList;
    }
}
