package org.jrenner.android_glances;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Context;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;
import com.actionbarsherlock.ActionBarSherlock;
import com.actionbarsherlock.app.SherlockActivity;
import org.jrenner.glances.*;
import org.jrenner.glances.Process;

import java.net.MalformedURLException;
import java.net.URL;
import java.text.ParseException;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;

public class Main extends SherlockActivity {
    private static final String TAG = "Main";
    private TextView mainText;
    private Button button;
    private GlancesData glancesData;

    private int m_interval = 5000; // 5 seconds by default, can be changed later
    private Handler m_handler;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        mainText = (TextView) findViewById(R.id.mainText);
        button = (Button) findViewById(R.id.button);
        button.setOnClickListener(buttonListener);
        m_handler = new Handler();

        ActionBarSherlock actionBar = getSherlock();
    }

    Runnable m_statusChecker = new Runnable()
    {
        @Override
        public void run() {
            update(); //this function can change value of m_interval.
            m_handler.postDelayed(m_statusChecker, m_interval);
        }
    };

    void startRepeatingTask()
    {
        m_statusChecker.run();
    }

    void stopRepeatingTask()
    {
        m_handler.removeCallbacks(m_statusChecker);
    }

    @Override
    public void onResume() {
        super.onResume();
        startRepeatingTask();
    }

    View.OnClickListener buttonListener = new View.OnClickListener() {
        public void onClick(View v) {
            if (v.getId() == R.id.button) {
                update();
            }
        }
    };

    public void update() {
        URL url = null;
        try {
            url = new URL("http://114.47.116.156:30000");
        } catch (MalformedURLException e) {
            Log.e(TAG, e.toString());
            mainText.setText("Cannot connect to url: " + url.toString());
            return;
        }
        GlancesAsyncTask task = new GlancesAsyncTask();
        int MAXIMUM_WAIT_TIME = 10;
        try {
            glancesData = task.execute(url).get(MAXIMUM_WAIT_TIME, TimeUnit.SECONDS);
        } catch (Exception e) {
            Log.e(TAG, "Timeout waiting for GlancesAsyncTask: " + e.toString());
        }
        // TODO use StringBuilder
        String text = "";
        if (glancesData == null) {
            Log.e(TAG, "glancesData was null");
            mainText.setText("glancesData was null");
            return;
        }
        text += "[Current time]: " + glancesData.getLastUpdate().toString();
        text += "\n" + glancesData.getSystemInfo().toString();
        List<Process> processList = glancesData.getProcessList();
        for (Process proc : processList) {
            if (proc.getMemoryPercent() > 5) {
                text += "\n" + proc.toString();
            }
        }
        List<NetworkInterface> nets = glancesData.getNetworkInterfaces();
        for (NetworkInterface net : nets) {
            if (!net.getInterfaceName().equals("wlan0"))
                continue;
            text += "\n" + net.toString();
        }
        text += "\n" + glancesData.getCpu().toString();
        text += "\n" + glancesData.getMemory().toString();
        List<FileSystem> fsList = glancesData.getFileSystems();
        for (FileSystem fs : fsList) {
            text += "\n" + fs.toString();
        }
        mainText.setText(text);
    }

    class GlancesAsyncTask extends AsyncTask<URL, Integer, GlancesData> {
        private static final String TAG = "GlancesAsyncTask";
        /** application context. */
        private Context context = getApplicationContext();
        /** progress dialog to show user that the backup is processing. */
        private URL serverURL;
        private GlancesData tempGlances;

        protected GlancesData doInBackground(URL... urls) {
            serverURL = urls[0];
            Log.i("jcr", "trying to get thing from: " + serverURL.toString());
            try {
                try {
                    tempGlances = new GlancesData(serverURL);
                } catch (ParseException e) {
                    Log.e(TAG, e.getMessage());
                }
            } catch (MalformedURLException e) {
                Log.e(TAG, e.toString());
            }
            return tempGlances;
        }

        @Override
        protected void onPostExecute(GlancesData glancesData) {

            // test a basic field to see if it was retrieved
            if (tempGlances.getCpu() != null) {
                Toast.makeText(context, "Retrieved Glances server data", Toast.LENGTH_SHORT).show();
            } else {
                Toast.makeText(context, "Error retrieving data from Glances server", Toast.LENGTH_SHORT).show();
            }
        }
    }
}
